package com.ruoyi.project.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.mapper.TrsDomainResultsMapper;
import com.ruoyi.project.domain.TrsDomainResults;
import com.ruoyi.project.service.ITrsDomainResultsService;
import com.ruoyi.common.core.text.Convert;

/**
 * 领域常识监测Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-03-24
 */
@Service
public class TrsDomainResultsServiceImpl implements ITrsDomainResultsService 
{
    @Autowired
    private TrsDomainResultsMapper trsDomainResultsMapper;

    /**
     * 查询领域常识监测
     * 
     * @param id 领域常识监测主键
     * @return 领域常识监测
     */
    @Override
    public TrsDomainResults selectTrsDomainResultsById(Long id)
    {
        return trsDomainResultsMapper.selectTrsDomainResultsById(id);
    }

    /**
     * 查询领域常识监测列表
     * 
     * @param trsDomainResults 领域常识监测
     * @return 领域常识监测
     */
    @Override
    public List<TrsDomainResults> selectTrsDomainResultsList(TrsDomainResults trsDomainResults)
    {
        return trsDomainResultsMapper.selectTrsDomainResultsList(trsDomainResults);
    }

    /**
     * 新增领域常识监测
     * 
     * @param trsDomainResults 领域常识监测
     * @return 结果
     */
    @Override
    public int insertTrsDomainResults(TrsDomainResults trsDomainResults)
    {
        return trsDomainResultsMapper.insertTrsDomainResults(trsDomainResults);
    }

    /**
     * 修改领域常识监测
     * 
     * @param trsDomainResults 领域常识监测
     * @return 结果
     */
    @Override
    public int updateTrsDomainResults(TrsDomainResults trsDomainResults)
    {
        return trsDomainResultsMapper.updateTrsDomainResults(trsDomainResults);
    }

    /**
     * 批量删除领域常识监测
     * 
     * @param ids 需要删除的领域常识监测主键
     * @return 结果
     */
    @Override
    public int deleteTrsDomainResultsByIds(String ids)
    {
        return trsDomainResultsMapper.deleteTrsDomainResultsByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除领域常识监测信息
     * 
     * @param id 领域常识监测主键
     * @return 结果
     */
    @Override
    public int deleteTrsDomainResultsById(Long id)
    {
        return trsDomainResultsMapper.deleteTrsDomainResultsById(id);
    }
}
